==> knative-model-5.0.2-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1/CloudEventOverridesFluentImpl.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

public class CloudEventOverridesFluentImpl<A extends CloudEventOverridesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements CloudEventOverridesFluent<A> {

    private Map<String,String> extensions;

    public CloudEventOverridesFluentImpl() {
    }

    public CloudEventOverridesFluentImpl(CloudEventOverrides instance) {
        this.withExtensions(instance.getExtensions()); 
    }

    public A addToExtensions(String key,String value) {
        if(this.extensions == null && key != null && value != null) { this.extensions = new LinkedHashMap<String,String>(); }
        if(key != null && value != null) {this.extensions.put(key, value);} return (A)this;
    }

    public A addToExtensions(Map<String,String> map) {
        if(this.extensions == null && map != null) { this.extensions = new LinkedHashMap<String,String>(); }
        if(map != null) { this.extensions.putAll(map);} return (A)this;
    }

    public A removeFromExtensions(String key) {
        if(this.extensions == null) { return (A) this; }
        if(key != null && this.extensions != null) {this.extensions.remove(key);} return (A)this;
    }

    public A removeFromExtensions(Map<String,String> map) {
        if(this.extensions == null) { return (A) this; }
        if(map != null) { for(Object key : map.keySet()) {if (this.extensions != null){this.extensions.remove(key);}}} return (A)this;
    }

    public Map<String,String> getExtensions() {
        return this.extensions;
    }

    public A withExtensions(Map<String,String> extensions) {
        if (extensions == null) { this.extensions =  null;} else {this.extensions = new LinkedHashMap<String,String>(extensions);} return (A) this;
    }

    public Boolean hasExtensions() {
        return this.extensions != null;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        CloudEventOverridesFluentImpl that = (CloudEventOverridesFluentImpl) o;
        if (extensions != null ? !extensions.equals(that.extensions) :that.extensions != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(extensions,  super.hashCode());
    }

}

==> knative-model-5.3.0-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1/CloudEventOverridesFluentImpl.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

public class CloudEventOverridesFluentImpl<A extends CloudEventOverridesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements CloudEventOverridesFluent<A> {

    private Map<String,String> extensions;

    public CloudEventOverridesFluentImpl() {
    }

    public CloudEventOverridesFluentImpl(CloudEventOverrides instance) {
        this.withExtensions(instance.getExtensions()); 
    }

    public A addToExtensions(String key,String value) {
        if(this.extensions == null && key != null && value != null) { this.extensions = new LinkedHashMap<String,String>(); }
        if(key != null && value != null) {this.extensions.put(key, value);} return (A)this;
    }

    public A addToExtensions(Map<String,String> map) {
        if(this.extensions == null && map != null) { this.extensions = new LinkedHashMap<String,String>(); }
        if(map != null) { this.extensions.putAll(map);} return (A)this;
    }

    public A removeFromExtensions(String key) {
        if(this.extensions == null) { return (A) this; }
        if(key != null && this.extensions != null) {this.extensions.remove(key);} return (A)this;
    }

    public A removeFromExtensions(Map<String,String> map) {
        if(this.extensions == null) { return (A) this; }
        if(map != null) { for(Object key : map.keySet()) {if (this.extensions != null){this.extensions.remove(key);}}} return (A)this;
    }

    public Map<String,String> getExtensions() {
        return this.extensions;
    }

    public <K extends Object,V extends Object>A withExtensions(Map<String,String> extensions) {
        if (extensions == null) { this.extensions =  null;} else {this.extensions = new LinkedHashMap<String,String>(extensions);} return (A) this;
    }

    public Boolean hasExtensions() {
        return this.extensions != null;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        CloudEventOverridesFluentImpl that = (CloudEventOverridesFluentImpl) o;
        if (extensions != null ? !extensions.equals(that.extensions) :that.extensions != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(extensions,  super.hashCode());
    }

}
